@@ -2,10 +2,14 @@ from typing import Optional
 
 from robotoff.prediction.types import Prediction
 from robotoff.taxonomy import Taxonomy
+from robotoff.triton import get_triton_inference_stub
 from robotoff.types import JSONType, NeuralCategoryClassifierModel, PredictionType
+from robotoff.utils import get_logger
 
 from . import keras_category_classifier_2_0, keras_category_classifier_3_0
 
+logger = get_logger(__name__)
+
 
 class CategoryPrediction:
     """CategoryPrediction stores information about a category classification prediction."""
@@ -69,6 +73,8 @@ class CategoryClassifier:
         :param neural_model_name: the name of the neural model to use to perform
             prediction. `keras_2_0` is used by default.
         """
+        logger.debug("predicting category with model %s", model_name)
+
         if threshold is None:
             threshold = 0.5
 
@@ -76,7 +82,7 @@ class CategoryClassifier:
             model_name = NeuralCategoryClassifierModel.keras_2_0
 
         if model_name == NeuralCategoryClassifierModel.keras_2_0:
-            predictions, debug = keras_category_classifier_2_0.predict(
+            raw_predictions, debug = keras_category_classifier_2_0.predict(
                 product, threshold
             )
         else:
@@ -97,12 +103,21 @@ class CategoryClassifier:
             else:
                 # Otherwise we fetch OCR texts from Product Opener
                 ocr_texts = keras_category_classifier_3_0.fetch_ocr_texts(product)
-            predictions, debug = keras_category_classifier_3_0.predict(
-                product, ocr_texts, model_name, threshold=threshold
+
+            triton_stub = get_triton_inference_stub()
+            image_embeddings = keras_category_classifier_3_0.generate_image_embeddings(
+                product, triton_stub
+            )
+            raw_predictions, debug = keras_category_classifier_3_0.predict(
+                product,
+                ocr_texts,
+                model_name,
+                threshold=threshold,
+                image_embeddings=image_embeddings,
             )
 
         category_predictions = [
-            CategoryPrediction(*item, model_name.value) for item in predictions
+            CategoryPrediction(*item, model_name.value) for item in raw_predictions
         ]
 
         if deepest_only:
@@ -114,7 +129,8 @@ class CategoryClassifier:
                 for x in self.taxonomy.find_deepest_nodes(taxonomy_nodes)
             ]
 
-        return [
+        predictions = [
             category_prediction.to_prediction()
             for category_prediction in category_predictions
-        ], debug
+        ]
+        return predictions, debug
